@@ -3,9 +3,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'AR': 'ar',
  'ARFLAGS': 'rc',
- 'ASDLGEN': '/usr/obj/ports/Python-2.7.8/Python-2.7.8/Parser/asdl_c.py',
- 'ASDLGEN_FILES': '/usr/obj/ports/Python-2.7.8/Python-2.7.8/Parser/asdl.py /usr/obj/ports/Python-2.7.8/Python-2.7.8/Parser/asdl_c.py',
- 'AST_ASDL': '/usr/obj/ports/Python-2.7.8/Python-2.7.8/Parser/Python.asdl',
+ 'ASDLGEN': './Parser/asdl_c.py',
+ 'ASDLGEN_FILES': './Parser/asdl.py ./Parser/asdl_c.py',
+ 'AST_ASDL': './Parser/Python.asdl',
  'AST_C': 'Python/Python-ast.c',
  'AST_C_DIR': 'Python',
  'AST_H': 'Include/Python-ast.h',
@@ -22,14 +22,14 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'BUILDPYTHON': 'python',
  'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-aliasing -O2 -pipe -DNDEBUG -O2 -pipe  -fPIC',
+ 'CFLAGS': '-fno-strict-aliasing -O2 -pipe -DNDEBUG -O2 -pipe   -fPIC',
  'CFLAGSFORSHARED': '-fPIC',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--enable-shared' '--srcdir=/usr/obj/ports/Python-2.7.8/Python-2.7.8' '--with-fpectl' '--with-threads' '--enable-ipv6' '--with-cxx_main' '--with-system-expat' '--with-system-ffi' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
+ 'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-shared' '--srcdir=/usr/obj/ports/Python-2.7.9/Python-2.7.9' '--with-fpectl' '--with-threads' '--enable-ipv6' '--with-cxx_main' '--with-system-expat' '--with-system-ffi' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python2.7',
  'COREPYTHONPATH': ':plat-openbsd5:lib-tk:lib-old',
- 'CPPFLAGS': '-I. -IInclude -I/usr/obj/ports/Python-2.7.8/Python-2.7.8/Include -I/usr/local/include',
+ 'CPPFLAGS': '-I. -IInclude -I./Include -I/usr/local/include',
  'CXX': 'c++ -pthread',
  'C_THREADS': 0,
  'DESTDIRS': '/usr/local /usr/local/lib /usr/local/lib/python2.7 /usr/local/lib/python2.7/lib-dynload',
@@ -43,10 +43,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
- 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
- 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
+ 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 1,
+ 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 0,
  'DYNLOADFILE': 'dynload_shlib.o',
  'ENABLE_IPV6': 1,
+ 'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
  'EXTRAMACHDEPPATH': '',
@@ -61,7 +62,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'GNULD': 'yes',
  'GRAMMAR_C': 'Python/graminit.c',
  'GRAMMAR_H': 'Include/graminit.h',
- 'GRAMMAR_INPUT': '/usr/obj/ports/Python-2.7.8/Python-2.7.8/Grammar/Grammar',
+ 'GRAMMAR_INPUT': './Grammar/Grammar',
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
@@ -350,16 +351,16 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HGBRANCH': '',
  'HGTAG': '',
  'HGVERSION': '',
- 'HOST_GNU_TYPE': 'mips64el-unknown-openbsd5.6',
+ 'HOST_GNU_TYPE': 'sparc64-unknown-openbsd5.7',
  'HURD_C_THREADS': 0,
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include /usr/local/include/python2.7 /usr/local/include/python2.7',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python2.7',
- 'INSTALL': '/usr/bin/install -c -o root -g bin',
- 'INSTALL_DATA': 'install -c -o root -g bin -m 444',
- 'INSTALL_PROGRAM': 'install -c -s -o root -g bin -m 555',
- 'INSTALL_SCRIPT': 'install -c -o root -g bin -m 555',
- 'INSTALL_SHARED': '/usr/bin/install -c -o root -g bin -m 555',
+ 'INSTALL': '/usr/obj/ports/Python-2.7.9/bin/install -c',
+ 'INSTALL_DATA': '/usr/obj/ports/Python-2.7.9/bin/install -c  -m 644',
+ 'INSTALL_PROGRAM': '/usr/obj/ports/Python-2.7.9/bin/install -c -s  -m 755',
+ 'INSTALL_SCRIPT': '/usr/obj/ports/Python-2.7.9/bin/install -c  -m 755',
+ 'INSTALL_SHARED': '/usr/obj/ports/Python-2.7.9/bin/install -c -m 555',
  'INSTSONAME': 'libpython2.7.so.0.0',
  'LDCXXSHARED': 'c++ -pthread -shared -fPIC',
  'LDFLAGS': '-L/usr/local/lib/',
@@ -395,7 +396,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'MAINCC': 'c++ -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': '/usr/obj/ports/Python-2.7.8/Python-2.7.8/Modules/makesetup',
+ 'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/local/man',
  'MEMTESTOPTS': '-l -x test_subprocess test_io test_lib2to3 \\ -x test_dl test___all__ test_fork1 \\',
  'MKDIR_P': 'mkdir -p',
@@ -406,7 +407,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'MVWDELCH_IS_EXPRESSION': 1,
  'OBJECT_OBJS': '\\',
  'OLDPATH': ':lib-old',
- 'OPT': '-DNDEBUG -O2 -pipe  -fPIC',
+ 'OPT': '-DNDEBUG -O2 -pipe   -fPIC',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -426,7 +427,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PLATMACPATH': ':plat-mac:plat-mac/lib-scriptpackages',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '/usr/obj/ports/Python-2.7.8/Python-2.7.8/Tools/pybench/pybench.py -n 2 --with-gc --with-syscheck',
+ 'PROFILE_TASK': './Tools/pybench/pybench.py -n 2 --with-gc --with-syscheck',
  'PSRCS': '\\',
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -440,7 +441,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PYTHON_FOR_BUILD': './python -E',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -O2 -pipe -DNDEBUG -O2 -pipe  -fPIC -I. -IInclude -I/usr/obj/ports/Python-2.7.8/Python-2.7.8/Include -I/usr/local/include -fPIC -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-fno-strict-aliasing -O2 -pipe -DNDEBUG -O2 -pipe   -fPIC -I. -IInclude -I./Include -I/usr/local/include -fPIC -DPy_BUILD_CORE',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_UNICODE_TYPE': 'unsigned short',
@@ -452,7 +453,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'RANLIB': 'ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/home/ports/Python-2.7.8/Python-2.7.8',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.9/Python-2.7.9',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '',
@@ -481,7 +482,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF__BOOL': 1,
  'SO': '.so',
  'SRCDIRS': 'Parser Grammar Objects Python Modules Mac',
- 'SRC_GDB_HOOKS': '/usr/obj/ports/Python-2.7.8/Python-2.7.8/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRINGLIB_HEADERS': '\\',
@@ -495,8 +496,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'TCLTK_LIBS': '',
  'TESTOPTS': '-l',
  'TESTPATH': '',
- 'TESTPROG': '/usr/obj/ports/Python-2.7.8/Python-2.7.8/Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/ports/Python-2.7.8/Python-2.7.8 ./python -Wd -3 -E -tt',
+ 'TESTPROG': './Lib/test/regrtest.py',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.9/Python-2.7.9 ./python -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -507,7 +508,6 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'USE_TOOLBOX_OBJECT_GLUE': 0,
  'VA_LIST_IS_ARRAY': 0,
  'VERSION': '2.7',
- 'VPATH': '/usr/obj/ports/Python-2.7.8/Python-2.7.8',
  'WANT_SIGFPE_HANDLER': 1,
  'WANT_WCTYPE_FUNCTIONS': 0,
  'WINDOW_HAS_FLAGS': 1,
@@ -521,11 +521,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/home/ports/Python-2.7.8/Python-2.7.8',
- 'abs_srcdir': '/usr/obj/ports/Python-2.7.8/Python-2.7.8',
- 'build': 'mips64el-unknown-openbsd5.6',
+ 'abs_builddir': '/usr/obj/ports/Python-2.7.9/Python-2.7.9',
+ 'abs_srcdir': '/usr/obj/ports/Python-2.7.9/Python-2.7.9',
+ 'build': 'sparc64-unknown-openbsd5.7',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
- 'host': 'mips64el-unknown-openbsd5.6',
+ 'host': 'sparc64-unknown-openbsd5.7',
  'prefix': '/usr/local',
- 'srcdir': '/usr/obj/ports/Python-2.7.8/Python-2.7.8'}
+ 'srcdir': '.'}
